# NMF with missing values

Based on the implementation by [Tom Dupré la Tour](http://tomdlt.github.io/) and forked from [Igor Gotlibovych](https://github.com/ig248).

- https://github.com/scikit-learn/scikit-learn/pull/8474
- https://github.com/TomDLT/scikit-learn/tree/nmf_missing
- https://github.com/ig248/nmf-contrib